Documentação ViralQC
====================

**ViralQC** é uma ferramenta e pacote Python desenvolvido para identificação de vírus e controle de qualidade a partir de arquivos FASTA.

.. note::
   This documentation is also available in **English**: https://viralqc.readthedocs.io/en/latest/

.. toctree::
   :maxdepth: 2
   :caption: Conteúdo

   index
   installation
   configuration
   scoring
   commands
   adding-datasets
   output
   examples
   troubleshooting


Índices e tabelas
=================

* :ref:`genindex`
* :ref:`search`
